==> haskell-temporary-1.2.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.2.1.1
id: temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG
key: temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG
license: BSD3
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support
description:
    Functions for creating temporary files and directories.
category: System, Utils
exposed: True
indefinite: False
exposed-modules:
    System.IO.Temp
abi: ab0f4b4f4a78e7c697cf1bced8c58e9c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/temporary-1.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/temporary-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/temporary-1.2.1.1
hs-libraries: HStemporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG
depends:
    base-4.10.1.0 filepath-1.4.1.2 directory-1.3.0.2
    transformers-0.5.2.0 exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT
    unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT=f624bf973f8eeff6578fe95732b4e11a
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.2.1.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.2.1.1
id: temporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2
key: temporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2
license: BSD3
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support
description:
    Functions for creating temporary files and directories.
category: System, Utils
exposed: True
indefinite: False
exposed-modules:
    System.IO.Temp
abi: 0ece841d14e2532f171448f112ccf0bd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/temporary-1.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/temporary-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/temporary-1.2.1.1
hs-libraries: HStemporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2
depends:
    base-4.10.1.0 filepath-1.4.1.2 directory-1.3.0.2
    transformers-0.5.2.0 exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
